<?php
/*
Plugin Name: Earth Observatory IOTD Widget
Plugin URI: http://henrypatton.org/earth-observatory-iotd
Description: Provides a widget to display the NASA Earth Observatory's Image of the Day and/or RSS feed on your sidebar.
Author: Henry Patton
Version: 1.0
Author URI: http://henrypatton.org
Licence: GPL3

Copyright 2012  Henry Patton  (email : henry@henrypatton.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Start class eoiod_img //

	class eoiod_img extends WP_Widget {

	// Constructor //

		function eoiod_img() {
			$widget_ops = array( 'classname' => 'eoiod_img', 'description' => "Displays the NASA Earth Observatory Image of the Day and/or the RSS feed." ); // Widget Settings
			$control_ops = array( 'id_base' => 'eoiod_img' ); // Widget Control Settings
			$this->WP_Widget( 'eoiod_img', "EO Image of the Day", $widget_ops, $control_ops ); // Create the widget
		}

	// Extract Args //

		function widget($args, $instance) {
			extract( $args );
			$title2		= apply_filters('widget_title', $instance['title']);
			$img_width 	= $instance['image_width'];
			$show_image 	= isset($instance['show_image']) ? $instance['show_image'] : false ;
			$show_text 	= isset($instance['show_text']) ? $instance['show_text'] : false ;
			$show_title 	= isset($instance['show_imgtitle']) ? $instance['show_imgtitle'] : false ;
			$show_feed	= isset($instance['show_feed']) ? $instance['show_feed'] : false ;
			$number 	= $instance['feed_number']; 

	// Before widget //

			echo $before_widget;

	// Title of widget //

			if ( $show_title ) { echo $before_title . $title2 . $after_title; }

	// Widget output //
			define('IODFOLDER', basename( dirname(__FILE__) ) );
			define('IOD_ABSPATH', trailingslashit( str_replace("\\","/", WP_PLUGIN_DIR . '/' . IODFOLDER ) ) );
			// Get RSS Feed(s)
			include_once(ABSPATH . WPINC . '/feed.php');
			
			// Set the cache time for SimplePie
			add_filter( 'wp_feed_cache_transient_lifetime', create_function( '$a', "return 3600;" ) ); // cache refresh 1 hour
			
			// Get a SimplePie feed object from the specified feed source.
			$rss = fetch_feed('http://earthobservatory.nasa.gov/Feeds/rss/eo_iotd.rss');
			
			    
			
			if (!is_wp_error( $rss ) ) : // Checks that the object is created correctly 
			    // Limit to top entry
			    $maxitems = $rss->get_item_quantity(1); 
			
			    // Build an array of all the items
			    $rss_items = $rss->get_items(0, $maxitems);
			endif;
			?>
			
	
			<?php if ($maxitems == 0) echo '<li>No items.</li>';
			elseif ($show_image){
			// Loop through each feed item and display each item as a hyperlink.
				foreach ( $rss_items as $item ) :
				    $thumbnail = $item->get_item_tags('http://search.yahoo.com/mrss/', 'thumbnail');
				    $thumbnail_url = $thumbnail[0]['attribs']['']['url'];
				    $base = basename($thumbnail_url);
				    $cache = plugins_url('earth-observatory-iotd-widget/cache/'.$base);
				    $cache_file = (IOD_ABSPATH."cache/".$base);
				    if (file_exists($cache_file)){ // check if have latest thumbnail
					// exists
				    }
				    else{
					foreach (glob(IOD_ABSPATH."cache/*.jpg") as $filename){                                
						unlink ($filename);}
					copy($thumbnail_url,$cache_file);
					}
				    ?> 
				    <a href='<?php echo esc_url( $item->get_permalink());?>' target='_blank'><img src='<?php echo ($cache);?>' width='<?php echo ($img_width);?>' /></a><?php
				    if ($show_text) { ?>
				    <p><?php echo $item->get_date('j M | ').$item->get_description();
				    }?>
				    <a href='<?php echo esc_url( $item->get_permalink());?>' target='_blank'>[Read More]</a></p>
				    
				<?php endforeach; 
			}
			
			if ($show_feed){
				$feed_number = $rss->get_item_quantity($number);
				if ($show_image){
					$rss_items2 = $rss->get_items(1,$feed_number);  // retrieve previous days (start 1 for yesterday)
				}
				else{
					$rss_items2 = $rss->get_items(0,$feed_number);  // retrieve previous days (start 0 for today if no image)
				}
				?>	
				<ul><?php
				foreach ($rss_items2 as $item) :?>
					<li>
					<?php echo esc_html( $item->get_date('j M | '));?><a href='<?php echo esc_url( $item->get_permalink() ); ?>' title='<?php echo $item->get_description(); ?>' target='_blank'><?php echo ($item->get_title()); ?></a>
				</li>
				<?php endforeach; ?>
				</ul><?php
			}
	// After widget //

			echo $after_widget;
		}

	// Update Settings //

		function update($new_instance, $old_instance) {
			$instance['title'] = strip_tags($new_instance['title']);
			$instance['image_width'] = strip_tags($new_instance['image_width']);
			$instance['show_image'] = $new_instance['show_image'];
			$instance['show_text'] = $new_instance['show_text'];
			$instance['feed_number'] = strip_tags($new_instance['feed_number']);
			$instance['show_feed'] = $new_instance['show_feed'];
			$instance['show_imgtitle'] = $new_instance['show_imgtitle'];
			return $instance;
		}

	// Widget Control Panel //

		function form($instance) {

		$defaults = array( 'title' => "NASA EO Image of the Day", 'image_width' => 200, 'future', 'show_image' => true, 'show_text' => true, 'show_imgtitle' => true, 'show_feed' => false, 'feed_number' => 5 );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>'" type="text" value="<?php echo $instance['title']; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('show_image'); ?>"><?php _e('Show image?'); ?></label>
			<input type="checkbox" class="checkbox" <?php checked( $instance['show_image'], 'on' ); ?> id="<?php echo $this->get_field_id('show_image'); ?>" name="<?php echo $this->get_field_name('show_image'); ?>" />
			
			<label for="<?php echo $this->get_field_id('show_feed'); ?>"><?php _e('Show feed?'); ?></label>
			<input type="checkbox" class="checkbox" <?php checked( $instance['show_feed'], 'on' ); ?> id="<?php echo $this->get_field_id('show_feed'); ?>" name="<?php echo $this->get_field_name('show_feed'); ?>" />
		
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('image_width'); ?>"><?php _e('Image width (pixels)'); ?></label>
			<input style="width:20%" id="<?php echo $this->get_field_id('image_width'); ?>" name="<?php echo $this->get_field_name('image_width'); ?>" type="text" value="<?php echo $instance['image_width']; ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('show_text'); ?>"><?php _e("Today's image description?"); ?></label>
			<input type="checkbox" class="checkbox" <?php checked( $instance['show_text'], 'on' ); ?> id="<?php echo $this->get_field_id('show_text'); ?>" name="<?php echo $this->get_field_name('show_text'); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id('show_imgtitle'); ?>"><?php _e('Show widget title?'); ?></label>
			<input type="checkbox" class="checkbox" <?php checked( $instance['show_imgtitle'], 'on' ); ?> id="<?php echo $this->get_field_id('show_imgtitle'); ?>" name="<?php echo $this->get_field_name('show_imgtitle'); ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('feed_number'); ?>"><?php _e('# days in feed (max. 10)'); ?></label>
			<input style="width:20%" id="<?php echo $this->get_field_id('feed_number'); ?>" name="<?php echo $this->get_field_name('feed_number'); ?>" type="text" value="<?php echo $instance['feed_number']; ?>" />
		</p>
        <?php }

}

// End class eoiod_img

add_action('widgets_init', create_function('', 'return register_widget("eoiod_img");'));

?>